searchData={"items":[{"type":"module","title":"SQLert","doc":"SQLert allows you to create self-contained alert modules that monitor your database\nby running SQL queries at defined schedule.","ref":"SQLert.html"},{"type":"module","title":"Overview - SQLert","doc":"SQLert automatically discovers and runs alerts when your application starts.\nYou can also control alerts at runtime:\n\nSQLert allows you to define alerts that:\n  * Run SQL queries at regular intervals\n  * Check for specific conditions in your database\n  * Trigger notifications when conditions are met","ref":"SQLert.html#module-overview"},{"type":"module","title":"Core Components - SQLert","doc":"* `SQLert.Alert`    - Behaviour for defining your alerts\n  * `SQLert.Notifier` - Behaviour for implementing notification channels","ref":"SQLert.html#module-core-components"},{"type":"function","title":"SQLert.discoverable_alerts/0","doc":"Returns a list of all discoverable alerts.\n\nEvery module defined in the scope of the application implementing\nthe `SQLert.Alert` behaviour, it will be considered _discoverable_.","ref":"SQLert.html#discoverable_alerts/0"},{"type":"function","title":"Examples - SQLert.discoverable_alerts/0","doc":"iex> SQLert.discoverable_alerts()\n    [SQLertTest.DisabledAlert, SQLertTest.EnabledAlert]","ref":"SQLert.html#discoverable_alerts/0-examples"},{"type":"function","title":"SQLert.running_alerts/0","doc":"Returns a list of running alerts.","ref":"SQLert.html#running_alerts/0"},{"type":"function","title":"SQLert.version/0","doc":"Returns the version of SQLert.","ref":"SQLert.html#version/0"},{"type":"behaviour","title":"SQLert.Alert","doc":"Defines an SQL-based alert (Behaviour).\n\nSQLert alerts are modules that specify SQL queries to be executed on schedule,\nchecking for specific conditions in your database. When these conditions are met,\nalerts can trigger notifications through various channels.","ref":"SQLert.Alert.html"},{"type":"behaviour","title":"Alert Lifecycle - SQLert.Alert","doc":"Each alert runs in its own process and follows this lifecycle:\n\n  1. At the configured schedule, the alert's `query/0` callback is executed\n  2. The query result is passed to `handle_result/1`\n  3. If `handle_result/1` returns `{:alert, message, metadata}`, notifications are sent\n  4. The process waits for the next scheduled","ref":"SQLert.Alert.html#module-alert-lifecycle"},{"type":"behaviour","title":"Defining Alerts - SQLert.Alert","doc":"To define an alert, create a module that uses `SQLert.Alert` and implement\nthe required callbacks:\n\n    defmodule MyApp.Alerts.HighErrorRate do\n      use SQLert.Alert,\n        schedule: \"10 * * * *\"\n        enabled: true\n\n      @impl true\n      def query do\n        \"SELECT COUNT(*) FROM errors WHERE created_at > NOW() - INTERVAL '1 hour'\"\n      end\n\n      @impl true\n      def handle_result([[count]]}) when count > 100 do\n        {:alert, \"High error rate detected\", %{count: count}}\n      end\n      def handle_result(_) do\n        {:skip, %{count: 0}}\n      end\n\n      @impl true\n      def notifiers do\n        [MyApp.Alerts.Notifiers.Slack]\n      end\n    end","ref":"SQLert.Alert.html#module-defining-alerts"},{"type":"behaviour","title":"Configuration Options - SQLert.Alert","doc":"* `:schedule` - (String) Cron notation with the alert schedule. *REQUIRED*\n  * `:enabled`  - (Boolean) Whether this alert should run. Defaults to `Mix.env() == :prod`","ref":"SQLert.Alert.html#module-configuration-options"},{"type":"behaviour","title":"Query Types - SQLert.Alert","doc":"The `query/0` callback can return either a string SQL query or an Ecto query:\n\n    # Raw SQL\n    def query do\n      \"SELECT COUNT(*) FROM users WHERE last_login < NOW() - INTERVAL '30 days'\"\n    end\n\n    # Ecto query\n    def query do\n      from u in User,\n        where: u.last_login < ago(30, \"day\"),\n        select: count(u.id)\n    end","ref":"SQLert.Alert.html#module-query-types"},{"type":"behaviour","title":"Handling Results - SQLert.Alert","doc":"The `handle_result/1` callback receives the query result and must return one of:\n\n  * `{:alert, message, metadata}` - Trigger notifications with the given message\n  * `{:skip, metadata}` - Condition not met, skip notifications\n\nFor SQL queries, results come in the format `%{rows: [[value]]}`. For Ecto queries,\nyou receive the direct query result.","ref":"SQLert.Alert.html#module-handling-results"},{"type":"behaviour","title":"Notifications - SQLert.Alert","doc":"Alerts can have multiple notifiers that implement the `SQLert.Notifier` behaviour.\nDefine them in the `notifiers/0` callback:\n\n    def notifiers do\n      [\n        MyApp.Alerts.Notifiers.Slack,\n        MyApp.Alerts.Notifiers.Email\n      ]\n    end\n\nSee `SQLert.Notifier` for details on implementing notifiers.","ref":"SQLert.Alert.html#module-notifications"},{"type":"type","title":"SQLert.Alert.alert_result/0","doc":"","ref":"SQLert.Alert.html#t:alert_result/0"},{"type":"callback","title":"SQLert.Alert.handle_result/1","doc":"","ref":"SQLert.Alert.html#c:handle_result/1"},{"type":"callback","title":"SQLert.Alert.notifiers/0","doc":"","ref":"SQLert.Alert.html#c:notifiers/0"},{"type":"callback","title":"SQLert.Alert.query/0","doc":"","ref":"SQLert.Alert.html#c:query/0"},{"type":"type","title":"SQLert.Alert.query/0","doc":"","ref":"SQLert.Alert.html#t:query/0"},{"type":"type","title":"SQLert.Alert.t/0","doc":"","ref":"SQLert.Alert.html#t:t/0"},{"type":"behaviour","title":"SQLert.Notifier","doc":"Behaviour for implementing alert notification delivery.","ref":"SQLert.Notifier.html"},{"type":"behaviour","title":"Example - SQLert.Notifier","doc":"defmodule MyApp.SQLerts.SlackNotifier do\n      @behaviour SQLert.Notifier\n\n      @impl true\n      def deliver(alert) do\n        # Send to Slack\n        :ok\n      end\n    end","ref":"SQLert.Notifier.html#module-example"},{"type":"callback","title":"SQLert.Notifier.deliver/1","doc":"","ref":"SQLert.Notifier.html#c:deliver/1"},{"type":"extras","title":"SQLert","doc":"# SQLert\n\n> Monitor your database and trigger alerts based on SQL queries in Elixir\n\nSQLert allows you to create self-contained alert modules that monitor your database by running SQL queries at defined intervals. Perfect for monitoring business metrics, detecting anomalies, or tracking system health.","ref":"readme.html"},{"type":"extras","title":"Installation - SQLert","doc":"Add `sqlert` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:sqlert, \"~> 0.1.0\"}\n  ]\nend\n```\n\n2. Configure your repo in `config/config.exs`:\n\n      ```elixir\n      config :sqlert,\n        repo: MyApp.Repo\n      ```\n\n  3. Create an alert:\n\n      ```elixir\n      defmodule MyApp.Alerts.HighErrorRate do\n        use SQLert.Alert,\n          interval: :timer.minutes(15)\n\n        @impl true\n        def query do\n          \"SELECT COUNT(*) \n           FROM errors \n           WHERE created_at > NOW() - INTERVAL '1 hour'\"\n        end\n\n        @impl true\n        def handle_result(%{rows: [[count]]}) when count > 100 do\n          {:alert, \"High error rate detected\", %{count: count}}\n        end\n      end\n      ```\n\n\n       4. Implement a notifier (optional):\n\n      ```elixir\n      defmodule MyApp.Alerts.Notifiers.Slack do\n        @behaviour SQLert.Notifier\n\n        @impl true\n        def deliver(alert) do\n          # Send to Slack\n          :ok\n        end\n      end\n      ```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - SQLert","doc":"Create your first alert:\n\n```elixir\ndefmodule MyApp.Alerts.HighErrorRate do\n  use SQLert.Behaviour\n\n  @impl true\n  def query do\n    \"\"\"\n    SELECT COUNT(*) \n    FROM errors \n    WHERE created_at > NOW() - INTERVAL '1 hour'\n    \"\"\"\n  end\n\n  @impl true\n  def interval, do: :timer.minutes(30)\n\n  @impl true\n  def handle_result(%{rows: [[count]]}) when count > 100 do\n    # Send to Slack, email, etc.\n    notify(:warning, \"High error rate detected\", %{count: count})\n  end\nend\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Features - SQLert","doc":"- 🔄 Run SQL queries at configurable intervals\n- 🎯 Easy to implement custom alert handlers\n- 📊 Built-in metrics via Telemetry\n- 🔌 Pluggable notification system\n- 💪 Process isolation for each alert\n- 🧩 Simple integration with external services","ref":"readme.html#features"},{"type":"extras","title":"Alert Configuration - SQLert","doc":"Each alert is a module that implements the `SQLert.Behaviour`:\n\n- `query/0` - Returns the SQL query to execute\n- `interval/0` - Sets how often to run (defaults to 5 minutes)\n- `handle_result/1` - Processes the query result\n- `handle_error/1` - Handles any errors (optional)\n- `notifiers/0` - List of notification modules (optional)","ref":"readme.html#alert-configuration"},{"type":"extras","title":"Telemetry Events - SQLert","doc":"SQLert emits the following telemetry events:\n\n- `[:sql_alert, :check, :complete]` - When an alert check completes\n- `[:sql_alert, :query, :success]` - When a query succeeds\n- `[:sql_alert, :query, :error]` - When a query fails\n- `[:sql_alert, :handler, :error]` - When the result handler raises an error\n- `[:sql_alert, :metrics, :update]` - When metrics are updated","ref":"readme.html#telemetry-events"},{"type":"extras","title":"Custom Notifiers - SQLert","doc":"Implement the `SQLert.Notifier` behaviour to create custom notification handlers:\n\n```elixir\ndefmodule MyApp.Notifiers.Slack do\n  @behaviour SQLert.Notifier\n\n  @impl true\n  def deliver(notification) do\n    # Send to Slack\n    message = format_message(notification)\n    SlackAPI.post_message(message)\n  end\nend\n```","ref":"readme.html#custom-notifiers"},{"type":"extras","title":"License - SQLert","doc":"SQLert is released under the MIT License. See the LICENSE file for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}